==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Adres.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypAdresu;
import pl.topteam.dps.enums.Wojewodztwo;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Adres extends GenericDPSObject {
    /**
     * ADRES.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ADRES.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * ADRES.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * ADRES.FAX
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String fax;

    /**
     * ADRES.GMINA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String gmina;

    /**
     * ADRES.KOD_POCZTOWY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodPocztowy;

    /**
     * ADRES.MIEJSCOWOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String miejscowosc;

    /**
     * ADRES.NR_DOMU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nrDomu;

    /**
     * ADRES.NR_LOKALU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nrLokalu;

    /**
     * ADRES.PANSTWO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String panstwo;

    /**
     * ADRES.POCZTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String poczta;

    /**
     * ADRES.POWIAT
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String powiat;

    /**
     * ADRES.TELEFON
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String telefon;

    /**
     * ADRES.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypAdresu typ;

    /**
     * ADRES.ULICA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String ulica;

    /**
     * ADRES.WOJEWODZTWO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Wojewodztwo wojewodztwo;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ADRES.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ADRES.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ADRES.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * ADRES.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return ADRES.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * ADRES.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return ADRES.FAX
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getFax() {
        return fax;
    }

    /**
     * ADRES.FAX
     *
     * @param fax
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setFax(String fax) {
        this.fax = fax == null ? null : fax.trim();
    }

    /**
     * @return ADRES.GMINA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getGmina() {
        return gmina;
    }

    /**
     * ADRES.GMINA
     *
     * @param gmina
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGmina(String gmina) {
        this.gmina = gmina == null ? null : gmina.trim();
    }

    /**
     * @return ADRES.KOD_POCZTOWY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodPocztowy() {
        return kodPocztowy;
    }

    /**
     * ADRES.KOD_POCZTOWY
     *
     * @param kodPocztowy
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodPocztowy(String kodPocztowy) {
        this.kodPocztowy = kodPocztowy == null ? null : kodPocztowy.trim();
    }

    /**
     * @return ADRES.MIEJSCOWOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getMiejscowosc() {
        return miejscowosc;
    }

    /**
     * ADRES.MIEJSCOWOSC
     *
     * @param miejscowosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiejscowosc(String miejscowosc) {
        this.miejscowosc = miejscowosc == null ? null : miejscowosc.trim();
    }

    /**
     * @return ADRES.NR_DOMU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNrDomu() {
        return nrDomu;
    }

    /**
     * ADRES.NR_DOMU
     *
     * @param nrDomu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNrDomu(String nrDomu) {
        this.nrDomu = nrDomu == null ? null : nrDomu.trim();
    }

    /**
     * @return ADRES.NR_LOKALU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNrLokalu() {
        return nrLokalu;
    }

    /**
     * ADRES.NR_LOKALU
     *
     * @param nrLokalu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNrLokalu(String nrLokalu) {
        this.nrLokalu = nrLokalu == null ? null : nrLokalu.trim();
    }

    /**
     * @return ADRES.PANSTWO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getPanstwo() {
        return panstwo;
    }

    /**
     * ADRES.PANSTWO
     *
     * @param panstwo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPanstwo(String panstwo) {
        this.panstwo = panstwo == null ? null : panstwo.trim();
    }

    /**
     * @return ADRES.POCZTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getPoczta() {
        return poczta;
    }

    /**
     * ADRES.POCZTA
     *
     * @param poczta
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPoczta(String poczta) {
        this.poczta = poczta == null ? null : poczta.trim();
    }

    /**
     * @return ADRES.POWIAT
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getPowiat() {
        return powiat;
    }

    /**
     * ADRES.POWIAT
     *
     * @param powiat
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPowiat(String powiat) {
        this.powiat = powiat == null ? null : powiat.trim();
    }

    /**
     * @return ADRES.TELEFON
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTelefon() {
        return telefon;
    }

    /**
     * ADRES.TELEFON
     *
     * @param telefon
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTelefon(String telefon) {
        this.telefon = telefon == null ? null : telefon.trim();
    }

    /**
     * @return ADRES.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypAdresu getTyp() {
        return typ;
    }

    /**
     * ADRES.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypAdresu typ) {
        this.typ = typ;
    }

    /**
     * @return ADRES.ULICA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getUlica() {
        return ulica;
    }

    /**
     * ADRES.ULICA
     *
     * @param ulica
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUlica(String ulica) {
        this.ulica = ulica == null ? null : ulica.trim();
    }

    /**
     * @return ADRES.WOJEWODZTWO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Wojewodztwo getWojewodztwo() {
        return wojewodztwo;
    }

    /**
     * ADRES.WOJEWODZTWO
     *
     * @param wojewodztwo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWojewodztwo(Wojewodztwo wojewodztwo) {
        this.wojewodztwo = wojewodztwo;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Adres other = (Adres) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getFax() == null ? other.getFax() == null : this.getFax().equals(other.getFax()))
            && (this.getGmina() == null ? other.getGmina() == null : this.getGmina().equals(other.getGmina()))
            && (this.getKodPocztowy() == null ? other.getKodPocztowy() == null : this.getKodPocztowy().equals(other.getKodPocztowy()))
            && (this.getMiejscowosc() == null ? other.getMiejscowosc() == null : this.getMiejscowosc().equals(other.getMiejscowosc()))
            && (this.getNrDomu() == null ? other.getNrDomu() == null : this.getNrDomu().equals(other.getNrDomu()))
            && (this.getNrLokalu() == null ? other.getNrLokalu() == null : this.getNrLokalu().equals(other.getNrLokalu()))
            && (this.getPanstwo() == null ? other.getPanstwo() == null : this.getPanstwo().equals(other.getPanstwo()))
            && (this.getPoczta() == null ? other.getPoczta() == null : this.getPoczta().equals(other.getPoczta()))
            && (this.getPowiat() == null ? other.getPowiat() == null : this.getPowiat().equals(other.getPowiat()))
            && (this.getTelefon() == null ? other.getTelefon() == null : this.getTelefon().equals(other.getTelefon()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getUlica() == null ? other.getUlica() == null : this.getUlica().equals(other.getUlica()))
            && (this.getWojewodztwo() == null ? other.getWojewodztwo() == null : this.getWojewodztwo().equals(other.getWojewodztwo()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getFax() == null) ? 0 : getFax().hashCode());
        result = prime * result + ((getGmina() == null) ? 0 : getGmina().hashCode());
        result = prime * result + ((getKodPocztowy() == null) ? 0 : getKodPocztowy().hashCode());
        result = prime * result + ((getMiejscowosc() == null) ? 0 : getMiejscowosc().hashCode());
        result = prime * result + ((getNrDomu() == null) ? 0 : getNrDomu().hashCode());
        result = prime * result + ((getNrLokalu() == null) ? 0 : getNrLokalu().hashCode());
        result = prime * result + ((getPanstwo() == null) ? 0 : getPanstwo().hashCode());
        result = prime * result + ((getPoczta() == null) ? 0 : getPoczta().hashCode());
        result = prime * result + ((getPowiat() == null) ? 0 : getPowiat().hashCode());
        result = prime * result + ((getTelefon() == null) ? 0 : getTelefon().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getUlica() == null) ? 0 : getUlica().hashCode());
        result = prime * result + ((getWojewodztwo() == null) ? 0 : getWojewodztwo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", fax=").append(fax);
        sb.append(", gmina=").append(gmina);
        sb.append(", kodPocztowy=").append(kodPocztowy);
        sb.append(", miejscowosc=").append(miejscowosc);
        sb.append(", nrDomu=").append(nrDomu);
        sb.append(", nrLokalu=").append(nrLokalu);
        sb.append(", panstwo=").append(panstwo);
        sb.append(", poczta=").append(poczta);
        sb.append(", powiat=").append(powiat);
        sb.append(", telefon=").append(telefon);
        sb.append(", typ=").append(typ);
        sb.append(", ulica=").append(ulica);
        sb.append(", wojewodztwo=").append(wojewodztwo);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Adres.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypAdresu;
import pl.topteam.dps.enums.Wojewodztwo;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Adres extends GenericDPSObject {
    /**
     * ADRES.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ADRES.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * ADRES.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * ADRES.FAX
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String fax;

    /**
     * ADRES.GMINA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String gmina;

    /**
     * ADRES.KOD_POCZTOWY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodPocztowy;

    /**
     * ADRES.MIEJSCOWOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String miejscowosc;

    /**
     * ADRES.NR_DOMU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nrDomu;

    /**
     * ADRES.NR_LOKALU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nrLokalu;

    /**
     * ADRES.PANSTWO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String panstwo;

    /**
     * ADRES.POCZTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String poczta;

    /**
     * ADRES.POWIAT
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String powiat;

    /**
     * ADRES.TELEFON
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String telefon;

    /**
     * ADRES.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypAdresu typ;

    /**
     * ADRES.ULICA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String ulica;

    /**
     * ADRES.WOJEWODZTWO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Wojewodztwo wojewodztwo;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ADRES.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ADRES.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ADRES.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * ADRES.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return ADRES.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * ADRES.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return ADRES.FAX
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getFax() {
        return fax;
    }

    /**
     * ADRES.FAX
     *
     * @param fax
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setFax(String fax) {
        this.fax = fax == null ? null : fax.trim();
    }

    /**
     * @return ADRES.GMINA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getGmina() {
        return gmina;
    }

    /**
     * ADRES.GMINA
     *
     * @param gmina
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGmina(String gmina) {
        this.gmina = gmina == null ? null : gmina.trim();
    }

    /**
     * @return ADRES.KOD_POCZTOWY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodPocztowy() {
        return kodPocztowy;
    }

    /**
     * ADRES.KOD_POCZTOWY
     *
     * @param kodPocztowy
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodPocztowy(String kodPocztowy) {
        this.kodPocztowy = kodPocztowy == null ? null : kodPocztowy.trim();
    }

    /**
     * @return ADRES.MIEJSCOWOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getMiejscowosc() {
        return miejscowosc;
    }

    /**
     * ADRES.MIEJSCOWOSC
     *
     * @param miejscowosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiejscowosc(String miejscowosc) {
        this.miejscowosc = miejscowosc == null ? null : miejscowosc.trim();
    }

    /**
     * @return ADRES.NR_DOMU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNrDomu() {
        return nrDomu;
    }

    /**
     * ADRES.NR_DOMU
     *
     * @param nrDomu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNrDomu(String nrDomu) {
        this.nrDomu = nrDomu == null ? null : nrDomu.trim();
    }

    /**
     * @return ADRES.NR_LOKALU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNrLokalu() {
        return nrLokalu;
    }

    /**
     * ADRES.NR_LOKALU
     *
     * @param nrLokalu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNrLokalu(String nrLokalu) {
        this.nrLokalu = nrLokalu == null ? null : nrLokalu.trim();
    }

    /**
     * @return ADRES.PANSTWO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getPanstwo() {
        return panstwo;
    }

    /**
     * ADRES.PANSTWO
     *
     * @param panstwo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPanstwo(String panstwo) {
        this.panstwo = panstwo == null ? null : panstwo.trim();
    }

    /**
     * @return ADRES.POCZTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getPoczta() {
        return poczta;
    }

    /**
     * ADRES.POCZTA
     *
     * @param poczta
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPoczta(String poczta) {
        this.poczta = poczta == null ? null : poczta.trim();
    }

    /**
     * @return ADRES.POWIAT
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getPowiat() {
        return powiat;
    }

    /**
     * ADRES.POWIAT
     *
     * @param powiat
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPowiat(String powiat) {
        this.powiat = powiat == null ? null : powiat.trim();
    }

    /**
     * @return ADRES.TELEFON
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTelefon() {
        return telefon;
    }

    /**
     * ADRES.TELEFON
     *
     * @param telefon
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTelefon(String telefon) {
        this.telefon = telefon == null ? null : telefon.trim();
    }

    /**
     * @return ADRES.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypAdresu getTyp() {
        return typ;
    }

    /**
     * ADRES.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypAdresu typ) {
        this.typ = typ;
    }

    /**
     * @return ADRES.ULICA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getUlica() {
        return ulica;
    }

    /**
     * ADRES.ULICA
     *
     * @param ulica
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUlica(String ulica) {
        this.ulica = ulica == null ? null : ulica.trim();
    }

    /**
     * @return ADRES.WOJEWODZTWO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Wojewodztwo getWojewodztwo() {
        return wojewodztwo;
    }

    /**
     * ADRES.WOJEWODZTWO
     *
     * @param wojewodztwo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWojewodztwo(Wojewodztwo wojewodztwo) {
        this.wojewodztwo = wojewodztwo;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Adres other = (Adres) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getFax() == null ? other.getFax() == null : this.getFax().equals(other.getFax()))
            && (this.getGmina() == null ? other.getGmina() == null : this.getGmina().equals(other.getGmina()))
            && (this.getKodPocztowy() == null ? other.getKodPocztowy() == null : this.getKodPocztowy().equals(other.getKodPocztowy()))
            && (this.getMiejscowosc() == null ? other.getMiejscowosc() == null : this.getMiejscowosc().equals(other.getMiejscowosc()))
            && (this.getNrDomu() == null ? other.getNrDomu() == null : this.getNrDomu().equals(other.getNrDomu()))
            && (this.getNrLokalu() == null ? other.getNrLokalu() == null : this.getNrLokalu().equals(other.getNrLokalu()))
            && (this.getPanstwo() == null ? other.getPanstwo() == null : this.getPanstwo().equals(other.getPanstwo()))
            && (this.getPoczta() == null ? other.getPoczta() == null : this.getPoczta().equals(other.getPoczta()))
            && (this.getPowiat() == null ? other.getPowiat() == null : this.getPowiat().equals(other.getPowiat()))
            && (this.getTelefon() == null ? other.getTelefon() == null : this.getTelefon().equals(other.getTelefon()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getUlica() == null ? other.getUlica() == null : this.getUlica().equals(other.getUlica()))
            && (this.getWojewodztwo() == null ? other.getWojewodztwo() == null : this.getWojewodztwo().equals(other.getWojewodztwo()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getFax() == null) ? 0 : getFax().hashCode());
        result = prime * result + ((getGmina() == null) ? 0 : getGmina().hashCode());
        result = prime * result + ((getKodPocztowy() == null) ? 0 : getKodPocztowy().hashCode());
        result = prime * result + ((getMiejscowosc() == null) ? 0 : getMiejscowosc().hashCode());
        result = prime * result + ((getNrDomu() == null) ? 0 : getNrDomu().hashCode());
        result = prime * result + ((getNrLokalu() == null) ? 0 : getNrLokalu().hashCode());
        result = prime * result + ((getPanstwo() == null) ? 0 : getPanstwo().hashCode());
        result = prime * result + ((getPoczta() == null) ? 0 : getPoczta().hashCode());
        result = prime * result + ((getPowiat() == null) ? 0 : getPowiat().hashCode());
        result = prime * result + ((getTelefon() == null) ? 0 : getTelefon().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getUlica() == null) ? 0 : getUlica().hashCode());
        result = prime * result + ((getWojewodztwo() == null) ? 0 : getWojewodztwo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", fax=").append(fax);
        sb.append(", gmina=").append(gmina);
        sb.append(", kodPocztowy=").append(kodPocztowy);
        sb.append(", miejscowosc=").append(miejscowosc);
        sb.append(", nrDomu=").append(nrDomu);
        sb.append(", nrLokalu=").append(nrLokalu);
        sb.append(", panstwo=").append(panstwo);
        sb.append(", poczta=").append(poczta);
        sb.append(", powiat=").append(powiat);
        sb.append(", telefon=").append(telefon);
        sb.append(", typ=").append(typ);
        sb.append(", ulica=").append(ulica);
        sb.append(", wojewodztwo=").append(wojewodztwo);
        sb.append("]");
        return sb.toString();
    }
}
